@@ -18,22 +18,49 @@ import easydata as ed
         (ed.Float(), "-1224.1234", -1224.1234),
         (ed.Float(), "Was €", None),
         (ed.Float(), "3.330,90", None),
-        (ed.Float(), False, None),
-        (ed.Float(), True, None),
-        (ed.Float(parse_bool=True), True, 1.0),
-        (ed.Float(parse_bool=True), False, 0.0),
+        (ed.Float(parse_bool=False), False, None),
+        (ed.Float(parse_bool=False), True, None),
+        (ed.Float(), True, 1.0),
+        (ed.Float(), False, 0.0),
         (ed.Float(decimals=2), "-1224.1234", -1224.12),
         (ed.Float(decimals=2), "-1224.1294", -1224.13),
         (ed.Float(decimals=2), None, None),
+        (ed.SFloat(), 99.9424, 99.9424),
+        (ed.SFloat(), 99, 99.0),
+        (ed.SFloat(), 99.9, 99.9),
+        (ed.SFloat(), 99.900, 99.9),
+        (ed.SFloat(), 99.0, 99.0),
+        (ed.SFloat(), 0.99, 0.99),
+        (ed.SFloat(), 0.0001, 0.0001),
+        (ed.SFloat(), 0, 0.0),
+        (ed.SFloat(), "1224.24", 1224.24),
+        (ed.SFloat(), "-1224.1234", -1224.1234),
+        (ed.SFloat(), "Was €", None),
+        (ed.SFloat(), "3.330,90", None),
+        (ed.SFloat(), False, 0.0),
+        (ed.SFloat(), True, 1.0),
+        (ed.SFloat(decimals=2), "-1224.1234", -1224.12),
+        (ed.SFloat(decimals=2), "-1224.1294", -1224.13),
+        (ed.SFloat(decimals=2), None, None),
+        (ed.Int(), 99, 99),
         (ed.Int(), 99.0, 99),
-        (ed.Int(), 0.99, 0),
+        (ed.Int(), 124.5554, 124),
+        (ed.Int(), 0, 0),
         (ed.Int(), 0.0001, 0),
-        (ed.Int(), "1224.24", 1224),
-        (ed.Int(), "-1224.1234", -1224),
+        (ed.Int(), "1224", 1224),
+        (ed.Int(), "23847821061620291", 23847821061620291),
+        (ed.Int(), "-1224", -1224),
         (ed.Int(), False, None),
         (ed.Int(), True, None),
         (ed.Int(parse_bool=True), True, 1),
         (ed.Int(parse_bool=True), False, 0),
+        (ed.SInt(), 99.9, 99),
+        (ed.SInt(), "99.9", None),
+        (ed.SInt(), 99, 99),
+        (ed.SInt(), 0, 0),
+        (ed.SInt(), None, None),
+        (ed.SInt(default=0), None, 0),
+        (ed.SInt(), "23847821061620291", 23847821061620291),
         (ed.SearchFloat(), "Was 99.9€", 99.9),
         (ed.SearchFloat(), "Was 99,90", 99.9),
         (ed.SearchFloat(), "Was 3.330,90", 3330.9),
@@ -93,5 +120,5 @@ import easydata as ed
         ),
     ],
 )
-def test_float(parser, test_data, result):
+def test_number(parser, test_data, result):
     assert parser.parse(test_data) == result
