@@ -15,10 +15,19 @@ test_date_sentence = "It has happened on 10 Dec 2018 at 10:55:50."
         (ed.Date(), "17 Sep 2022", "09/17/2022"),
         (ed.Date(), "Sep 17 2022", "09/17/2022"),
         (ed.Date(), "Sep. 17 2022", "09/17/2022"),
+        (ed.Date(prefer_dates_from="future"), "jan 4", "01/04/2023"),
         (ed.YearSearch(), test_date_sentence, "2018"),
         (ed.YearSearch(), "Some player signed 2010 Open 139th (British Open)", "2010"),
         (ed.TimeSearch(), test_date_sentence, "10:55:50"),
         (ed.DateSearch(), test_date_sentence, "12/10/2018"),
+        (ed.DateSearch(), "dec 11", "12/11/2022"),
+        (ed.DateSearch(), "jan 4", "01/04/2022"),
+        (ed.DateSearch(prefer_dates_from="future"), "jan 4", "01/04/2023"),
+        (
+            ed.DateSearch(prefer_dates_from="future", remove_keys=[r"\."]),
+            "jan. 4",
+            "01/04/2023",
+        ),
         (ed.DateTimeSearch(), test_date_sentence, "12/10/2018 10:55:50"),
         (ed.Year(), "Fri, 10 Dec 2018 10:55:50", "2018"),
         (ed.Year(max_year=2017), "Fri, 10 Dec 2018 10:55:50", None),
